@@ -3,7 +3,9 @@ from __future__ import annotations
 import _io
 import multiprocessing
 from dataclasses import dataclass
+from enum import Enum
 from queue import Empty
+from typing import Any, Union
 
 s_line_template = 'S\t{low_scan}\t{high_scan}\t{mz}\n'
 i_line_template = 'I\t{keyword}\t{value}\n'
@@ -12,6 +14,24 @@ peak_line_template = '{mz} {intensity}\n'
 peak_line_charged_template = '{mz} {intensity} {charge}\n'
 
 
+class ILineKeywords(Enum):
+    PARENT_ID_KEYWORD = 'TIMSTOF_Parent_ID'
+    PRECURSOR_ID_KEYWORD = 'TIMSTOF_Precursor_ID'
+    OOK0_KEYWORD = 'Ion Mobility'
+    CCS_KEYWORD = 'CCS'
+    RETENTION_TIME_KEYWORD = 'RetTime'
+    COLLISION_ENERGY_KEYWORD = 'Collision_Energy'
+    ISOLATION_MZ_KEYWORD = 'Isolation_Mz'
+    ISOLATION_WIDTH_KEYWORD = 'Isolation_Width'
+    SCAN_NUMBER_BEGIN_KEYWORD = 'Scan_Number_Begin'
+    SCAN_NUMBER_END_KEYWORD = 'Scan_Number_End'
+    PRECURSOR_INTENSITY_KEYWORD = 'Intensity'
+    OOK0_SPECTRA_KEYWORD = 'OOK0_Spectra'
+    CCS_SPECTRA_KEYWORD = 'CCS_Spectra'
+    INTENSITY_SPECTRA_KEYWORD = 'Intensity_Spectra'
+    MZ_SPECTRA_KEYWORD = 'MZ_Spectra'
+
+
 @dataclass(slots=True)
 class Ms2Spectra:
     low_scan: int
@@ -24,6 +44,79 @@ class Ms2Spectra:
     intensity_spectra: list[float]
     charge_spectra: list[float]
 
+    @property
+    def parent_id(self) -> Union[str, None]: return self.info.get(ILineKeywords.PARENT_ID_KEYWORD)
+
+    @parent_id.setter
+    def parent_id(self, parent_id: Union[str, int]): self.info[ILineKeywords.PARENT_ID_KEYWORD] = str(parent_id)
+
+    @property
+    def precursor_id(self) -> Union[str, None]: return self.info.get(ILineKeywords.PRECURSOR_ID_KEYWORD)
+
+    @precursor_id.setter
+    def precursor_id(self, precursor_id: Union[str, int]): self.info[ILineKeywords.PRECURSOR_ID_KEYWORD] = str(precursor_id)
+
+    @property
+    def ook0(self) -> Union[str, None]: return self.info.get(ILineKeywords.OOK0_KEYWORD)
+
+    @ook0.setter
+    def ook0(self, ook0: Union[str, float]): self.info[ILineKeywords.OOK0_KEYWORD] = str(ook0)
+
+    @property
+    def ccs(self) -> Union[str, None]: return self.info.get(ILineKeywords.CCS_KEYWORD)
+
+    @ccs.setter
+    def ccs(self, ccs: Union[str, float]): self.info[ILineKeywords.CCS_KEYWORD] = str(ccs)
+
+    @property
+    def rt(self) -> Union[str, None]: return self.info.get(ILineKeywords.RETENTION_TIME_KEYWORD)
+
+    @rt.setter
+    def rt(self, rt: Union[str, float]): self.info[ILineKeywords.RETENTION_TIME_KEYWORD] = str(rt)
+
+    @property
+    def ce(self) -> Union[str, None]: return self.info.get(ILineKeywords.COLLISION_ENERGY_KEYWORD)
+
+    @ce.setter
+    def ce(self, ce: Union[str, float]): self.info[ILineKeywords.COLLISION_ENERGY_KEYWORD] = str(ce)
+
+    @property
+    def iso_mz(self) -> Union[str, None]: return self.info.get(ILineKeywords.ISOLATION_MZ_KEYWORD)
+
+    @iso_mz.setter
+    def iso_mz(self, iso_mz: Union[str, float]): self.info[ILineKeywords.ISOLATION_MZ_KEYWORD] = str(iso_mz)
+
+    @property
+    def iso_width(self) -> Union[str, None]: return self.info.get(ILineKeywords.ISOLATION_WIDTH_KEYWORD)
+
+    @iso_width.setter
+    def iso_width(self, iso_width: Union[str, float]): self.info[ILineKeywords.ISOLATION_WIDTH_KEYWORD] = str(iso_width)
+
+    @property
+    def scan_begin(self) -> Union[str, None]: return self.info.get(ILineKeywords.SCAN_NUMBER_BEGIN_KEYWORD)
+
+    @scan_begin.setter
+    def scan_begin(self, scan_begin: Union[str, int]): self.info[ILineKeywords.SCAN_NUMBER_BEGIN_KEYWORD] = str(scan_begin)
+
+    @property
+    def scan_end(self) -> Union[int, None]: return self.info.get(ILineKeywords.SCAN_NUMBER_END_KEYWORD)
+
+    @scan_end.setter
+    def scan_end(self, scan_end: Union[str, int]): self.info[ILineKeywords.SCAN_NUMBER_END_KEYWORD] = str(scan_end)
+
+    @property
+    def prec_intensity(self) -> Union[str, None]: return self.info.get(ILineKeywords.PRECURSOR_INTENSITY_KEYWORD)
+
+    @prec_intensity.setter
+    def prec_intensity(self, prec_intensity: Union[str, float]): self.info[ILineKeywords.PRECURSOR_INTENSITY_KEYWORD] = str(prec_intensity)
+
+    def serialize(self) -> str:
+        return _serialize_ms2_spectra(self)
+
+    @staticmethod
+    def deserialize(self, line: str) -> 'Ms2Spectra':
+        return _deserialize_ms2_spectra(line)
+
 
 def _serialize_ms2_spectra(ms2_spectra: Ms2Spectra) -> str:
     P = 4
